@@ -1,33 +1,11 @@
 ## row clustering testing -------------------------------------------------------
 test_that("reordering row clustering results produces correct results.", {
 
-    ## Check that reorder() produces correctly reordered results
-    set.seed(30)
-    n <- 30
-    p <- 5
-    long_df_sim <- data.frame(Y=factor(sample(1:3,n*p,replace=TRUE)),
-                              ROW=rep(1:n,times=p),COL=rep(1:p,each=n))
+    load("reorder_models_row.Rdata")
 
-    ## Make sure to test continuous and categorical covariates
-    xr1 <- runif(n, min=0, max=2)
-    xr2 <- sample(c("A","B"),size=n, replace=TRUE, prob=c(0.3,0.7))
-    xr3 <- factor(sample(1:4, size=n, replace=TRUE))
-
-    xc1 <- runif(p, min=-1, max=1)
-
-    long_df_sim$xr1 <- rep(xr1, times=5)
-    long_df_sim$xr2 <- rep(xr2, times=5)
-    long_df_sim$xr3 <- rep(xr3, times=5)
-    long_df_sim$xc1 <- rep(xc1, each=30)
-
-    # OSM results --------------------------------------------------------------
+    # OSM results ----
     ## Model 1 ----
-    ## NOTE! Need to use keep_all_params=TRUE in order to actually have some output
-    ## to reorder in EMstatus$params_every_iteration
-    orig <- clustord(Y~ROWCLUST*xr1+xr2*xr3+COL, model="OSM", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
-
+    orig <- orig_standard_OSM1
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
 
@@ -105,9 +83,7 @@ test_that("reordering row clustering results produces correct results.", {
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:6,8,7,9,10:14,16,15,17,18:25,27,26,28,29:30)])
 
     ## Model 2 ----
-    orig <- clustord(Y~ROWCLUST*COL+xc1, model="OSM", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_OSM2
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -178,9 +154,7 @@ test_that("reordering row clustering results produces correct results.", {
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration)
 
     ## Model 3 ----
-    orig <- clustord(Y~ROWCLUST*xc1, model="OSM", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_OSM3
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -249,10 +223,8 @@ test_that("reordering row clustering results produces correct results.", {
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration)
 
     # POM results --------------------------------------------------------------
-    ## Model 1 ----
-    orig <- clustord(Y~ROWCLUST*xr1+xr2*xr3+COL, model="POM", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    ## Model 1
+    orig <- orig_standard_POM1
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -327,11 +299,8 @@ test_that("reordering row clustering results produces correct results.", {
 
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:2,4,3,5,6:10,12,11,13,14:21,23,22,24,25:26)])
 
-
     ## Model 2 ----
-    orig <- clustord(Y~ROWCLUST*COL+xc1, model="POM", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_POM2
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -406,9 +375,7 @@ test_that("reordering row clustering results produces correct results.", {
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:2,4,3,5,6:10,12,11,13,15,14,16,18,17,19,21,20,22,24,23,25,26,28,27,29,30:31)])
 
     ## Model 3 ----
-    orig <- clustord(Y~ROWCLUST*xc1, model="POM", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_POM3
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -483,23 +450,9 @@ test_that("reordering row clustering results produces correct results.", {
 
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:2,4,3,5,7,6,8,9,11,10,12,13:14)])
 
-
-    ## Binary results ----------------------------------------------------------
-    long_df_sim <- data.frame(Y=factor(sample(1:2,n*p,replace=TRUE)),
-                              ROW=rep(1:n,times=p),COL=rep(1:p,each=n))
-    n <- 30
-    p <- 5
-
-    ## Make sure to test continuous and categorical covariates
-    long_df_sim$xr1 <- rep(xr1, times=5)
-    long_df_sim$xr2 <- rep(xr2, times=5)
-    long_df_sim$xr3 <- rep(xr3, times=5)
-    long_df_sim$xc1 <- rep(xc1, each=30)
-
+    # Binary results ----
     ## Model 1 ----
-    orig <- clustord(Y~ROWCLUST*xr1+xr2*xr3+COL, model="Binary", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_Binary1
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -576,9 +529,7 @@ test_that("reordering row clustering results produces correct results.", {
 
 
     ## Model 2 ----
-    orig <- clustord(Y~ROWCLUST*COL+xc1, model="Binary", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_Binary2
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -653,9 +604,7 @@ test_that("reordering row clustering results produces correct results.", {
 
 
     ## Model 3 ----
-    orig <- clustord(Y~ROWCLUST*xc1, model="Binary", RG=3,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = TRUE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_standard_Binary3
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -727,39 +676,11 @@ test_that("reordering row clustering results produces correct results.", {
 
 ## row clustering first-element-zero testing -----------------------------------
 test_that("reordering row clustering results with other constraint produces correct results.", {
-
-    ## Check that reorder() produces correctly reordered results
-    set.seed(30)
-    n <- 30
-    p <- 5
-    long_df_sim <- data.frame(Y=factor(sample(1:3,n*p,replace=TRUE)),
-                              ROW=rep(1:n,times=p),COL=rep(1:p,each=n))
-
-    ## Make sure to test continuous and categorical covariates
-    xr1 <- runif(n, min=0, max=2)
-    xr2 <- sample(c("A","B"),size=n, replace=TRUE, prob=c(0.3,0.7))
-    xr3 <- factor(sample(1:4, size=n, replace=TRUE))
-
-    xc1 <- runif(p, min=-1, max=1)
-
-    long_df_sim$xr1 <- rep(xr1, times=5)
-    long_df_sim$xr2 <- rep(xr2, times=5)
-    long_df_sim$xr3 <- rep(xr3, times=5)
-    long_df_sim$xc1 <- rep(xc1, each=30)
-
-    ## NOTE: Using RG = 4 here (compared with RG = 3 above)
-    ## because for RG = 3 with first cluster effect set to 0 there are
-    ## only 2 possible orderings of the non-zero cluster effects, so always one
-    ## of the increasing or decreasing order will be the same as the original
-    ## model ordering.
-    ## Increasing to 4 clusters increases the chance of having both directions
-    ## be different from the original ordering
+    load("reorder_models_row.Rdata")
 
     # OSM results --------------------------------------------------------------
     ## Model 1 ----
-    orig <- clustord(Y~ROWCLUST*xr1+xr2*xr3+COL, model="OSM", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_OSM1
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -858,10 +779,7 @@ test_that("reordering row clustering results with other constraint produces corr
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:6,7,8,10,9,11:15,16,17,19,18,20:27,28,29,31,30,32:33)])
 
     ## Model 2 ----
-    orig <- clustord(Y~ROWCLUST*COL+xc1, model="OSM", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
-
+    orig <- orig_first_elt_OSM2
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
 
@@ -942,9 +860,7 @@ test_that("reordering row clustering results with other constraint produces corr
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:6,7,10,8,9,11:15,16,19,17,18,20,23,21,22,24,27,25,26,28,31,29,30,32,35,33,34,36,37,40,38,39,41:42)])
 
     ## Model 3 ----
-    orig <- clustord(Y~ROWCLUST*xc1, model="OSM", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_OSM3
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -1024,9 +940,7 @@ test_that("reordering row clustering results with other constraint produces corr
 
     # POM results --------------------------------------------------------------
     ## Model 1 ----
-    orig <- clustord(Y~ROWCLUST*xr1+xr2*xr3+COL, model="POM", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_POM1
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -1103,9 +1017,7 @@ test_that("reordering row clustering results with other constraint produces corr
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:2,3,5,6,4,7:11,12,14,15,13,16:23,24,26,27,25,28:29)])
 
     ## Model 2 ----
-    orig <- clustord(Y~ROWCLUST*COL+xc1, model="POM", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_POM2
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -1188,9 +1100,7 @@ test_that("reordering row clustering results with other constraint produces corr
 
 
     ## Model 3 ----
-    orig <- clustord(Y~ROWCLUST*xc1, model="POM", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_POM3
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -1266,23 +1176,10 @@ test_that("reordering row clustering results with other constraint produces corr
 
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1:2,3,5,4,6,7,9,8,10,11,12,14,13,15,16:17)])
 
-    ## Binary results ----------------------------------------------------------
-    set.seed(1)
-    long_df_sim <- data.frame(Y=factor(sample(1:2,n*p,replace=TRUE)),
-                              ROW=rep(1:n,times=p),COL=rep(1:p,each=n))
-    n <- 30
-    p <- 5
-
-    ## Make sure to test continuous and categorical covariates
-    long_df_sim$xr1 <- rep(xr1, times=5)
-    long_df_sim$xr2 <- rep(xr2, times=5)
-    long_df_sim$xr3 <- rep(xr3, times=5)
-    long_df_sim$xc1 <- rep(xc1, each=30)
 
+    ## Binary results ----
     ## Model 1 ----
-    orig <- clustord(Y~ROWCLUST*xr1+xr2*xr3+COL, model="Binary", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_Binary1
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -1353,9 +1250,7 @@ test_that("reordering row clustering results with other constraint produces corr
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration)
 
     ## Model 2 ----
-    orig <- clustord(Y~ROWCLUST*COL+xc1, model="Binary", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_Binary2
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
@@ -1434,11 +1329,8 @@ test_that("reordering row clustering results with other constraint produces corr
 
     expect_equal(reord$EMstatus$params_every_iteration, orig$EMstatus$params_every_iteration[,c(1,2,5,3,4,6:10,11,14,12,13,15,18,16,17,19,22,20,21,23,26,24,25,27,30,28,29,31,32,35,33,34,36:37)])
 
-
     ## Model 3 ----
-    orig <- clustord(Y~ROWCLUST*xc1, model="Binary", RG=4,
-                     long_df=long_df_sim, nstarts=1, constraint_sum_zero = FALSE,
-                     control_EM=list(maxiter=3,maxiter_start=2,keep_all_params=TRUE))
+    orig <- orig_first_elt_Binary3
 
     ### Rows increasing ----
     reord <- reorder(orig, "row", decreasing=FALSE)
